var NAVTREEINDEX11 =
{
"mdaDegradeController_8cpp.html":[3,0,76],
"mdaDegradeController_8h.html":[3,0,77],
"mdaDegradeProcessor_8cpp.html":[3,0,78],
"mdaDegradeProcessor_8h.html":[3,0,79],
"mdaDelayController_8cpp.html":[3,0,80],
"mdaDelayController_8h.html":[3,0,81],
"mdaDelayProcessor_8cpp.html":[3,0,82],
"mdaDelayProcessor_8h.html":[3,0,83],
"mdaDetuneController_8cpp.html":[3,0,84],
"mdaDetuneController_8h.html":[3,0,85],
"mdaDetuneProcessor_8cpp.html":[3,0,86],
"mdaDetuneProcessor_8cpp.html#aa893c2c75e0d3d0258e09fbd136ffaed":[3,0,86,0],
"mdaDetuneProcessor_8h.html":[3,0,87],
"mdaDitherController_8cpp.html":[3,0,88],
"mdaDitherController_8h.html":[3,0,89],
"mdaDitherProcessor_8cpp.html":[3,0,90],
"mdaDitherProcessor_8h.html":[3,0,91],
"mdaDubDelayController_8cpp.html":[3,0,92],
"mdaDubDelayController_8h.html":[3,0,93],
"mdaDubDelayProcessor_8cpp.html":[3,0,94],
"mdaDubDelayProcessor_8h.html":[3,0,95],
"mdaDynamicsController_8cpp.html":[3,0,100],
"mdaDynamicsController_8h.html":[3,0,101],
"mdaDynamicsProcessor_8cpp.html":[3,0,102],
"mdaDynamicsProcessor_8h.html":[3,0,103],
"mdaEPianoController_8cpp.html":[3,0,104],
"mdaEPianoController_8h.html":[3,0,105],
"mdaEPianoData_8h.html":[3,0,106],
"mdaEPianoData_8h.html#ab266be229d28fa6b6be56ab0b4e92de7":[3,0,106,0],
"mdaEPianoProcessor_8cpp.html":[3,0,107],
"mdaEPianoProcessor_8cpp.html#aac1866175a2578574fc07c16e566c4fc":[3,0,107,1],
"mdaEPianoProcessor_8cpp.html#ac16f5b88e42015f1db52b238012154ce":[3,0,107,2],
"mdaEPianoProcessor_8cpp.html#ae468832efa6adf5e9a96cabd8f878b47":[3,0,107,0],
"mdaEPianoProcessor_8h.html":[3,0,108],
"mdaImageController_8cpp.html":[3,0,110],
"mdaImageController_8h.html":[3,0,111],
"mdaImageProcessor_8cpp.html":[3,0,112],
"mdaImageProcessor_8h.html":[3,0,113],
"mdaJX10Controller_8cpp.html":[3,0,114],
"mdaJX10Controller_8h.html":[3,0,115],
"mdaJX10Processor_8cpp.html":[3,0,116],
"mdaJX10Processor_8cpp.html#a4912c64aec0c943b7985db6cb61ff83a":[3,0,116,3],
"mdaJX10Processor_8cpp.html#a598a3330b3c21701223ee0ca14316eca":[3,0,116,2],
"mdaJX10Processor_8cpp.html#aac1866175a2578574fc07c16e566c4fc":[3,0,116,1],
"mdaJX10Processor_8cpp.html#ad42aa2404559d4a465d5d45e857f2881":[3,0,116,4],
"mdaJX10Processor_8cpp.html#ae468832efa6adf5e9a96cabd8f878b47":[3,0,116,0],
"mdaJX10Processor_8h.html":[3,0,117],
"mdaLeslieController_8cpp.html":[3,0,118],
"mdaLeslieController_8h.html":[3,0,119],
"mdaLeslieProcessor_8cpp.html":[3,0,120],
"mdaLeslieProcessor_8h.html":[3,0,121],
"mdaLimiterController_8cpp.html":[3,0,122],
"mdaLimiterController_8h.html":[3,0,123],
"mdaLimiterProcessor_8cpp.html":[3,0,124],
"mdaLimiterProcessor_8h.html":[3,0,125],
"mdaLoudnessController_8cpp.html":[3,0,126],
"mdaLoudnessController_8h.html":[3,0,127],
"mdaLoudnessProcessor_8cpp.html":[3,0,128],
"mdaLoudnessProcessor_8h.html":[3,0,129],
"mdaMultiBandController_8cpp.html":[3,0,130],
"mdaMultiBandController_8h.html":[3,0,131],
"mdaMultiBandProcessor_8cpp.html":[3,0,132],
"mdaMultiBandProcessor_8h.html":[3,0,133],
"mdaOverdriveController_8cpp.html":[3,0,134],
"mdaOverdriveController_8h.html":[3,0,135],
"mdaOverdriveProcessor_8cpp.html":[3,0,136],
"mdaOverdriveProcessor_8h.html":[3,0,137],
"mdaParameter_8cpp.html":[3,0,138],
"mdaParameter_8h.html":[3,0,139],
"mdaPianoController_8cpp.html":[3,0,140],
"mdaPianoController_8h.html":[3,0,141],
"mdaPianoData_8h.html":[3,0,142],
"mdaPianoData_8h.html#a95bc615d5afb12081d11c5548fbca956":[3,0,142,0],
"mdaPianoProcessor_8cpp.html":[3,0,143],
"mdaPianoProcessor_8cpp.html#aac1866175a2578574fc07c16e566c4fc":[3,0,143,0],
"mdaPianoProcessor_8h.html":[3,0,144],
"mdaRePsychoController_8cpp.html":[3,0,145],
"mdaRePsychoController_8h.html":[3,0,146],
"mdaRePsychoProcessor_8cpp.html":[3,0,147],
"mdaRePsychoProcessor_8h.html":[3,0,148],
"mdaRezFilterController_8cpp.html":[3,0,149],
"mdaRezFilterController_8h.html":[3,0,150],
"mdaRezFilterProcessor_8cpp.html":[3,0,151],
"mdaRezFilterProcessor_8h.html":[3,0,152],
"mdaRingModController_8cpp.html":[3,0,153],
"mdaRingModController_8h.html":[3,0,154],
"mdaRingModProcessor_8cpp.html":[3,0,155],
"mdaRingModProcessor_8h.html":[3,0,156],
"mdaRoundPanController_8cpp.html":[3,0,157],
"mdaRoundPanController_8h.html":[3,0,158],
"mdaRoundPanProcessor_8cpp.html":[3,0,159],
"mdaRoundPanProcessor_8h.html":[3,0,160],
"mdaShepardController_8cpp.html":[3,0,161],
"mdaShepardController_8h.html":[3,0,162],
"mdaShepardProcessor_8cpp.html":[3,0,163],
"mdaShepardProcessor_8h.html":[3,0,164],
"mdaSpecMeterController_8cpp.html":[3,0,165],
"mdaSpecMeterController_8h.html":[3,0,166],
"mdaSpecMeterProcessor_8cpp.html":[3,0,167],
"mdaSpecMeterProcessor_8cpp.html#aac1866175a2578574fc07c16e566c4fc":[3,0,167,0],
"mdaSpecMeterProcessor_8h.html":[3,0,168],
"mdaSplitterController_8cpp.html":[3,0,169],
"mdaSplitterController_8h.html":[3,0,170],
"mdaSplitterProcessor_8cpp.html":[3,0,171],
"mdaSplitterProcessor_8h.html":[3,0,172],
"mdaStereoController_8cpp.html":[3,0,173],
"mdaStereoController_8h.html":[3,0,174],
"mdaStereoProcessor_8cpp.html":[3,0,175],
"mdaStereoProcessor_8h.html":[3,0,176],
"mdaSubSynthController_8cpp.html":[3,0,177],
"mdaSubSynthController_8h.html":[3,0,178],
"mdaSubSynthProcessor_8cpp.html":[3,0,179],
"mdaSubSynthProcessor_8h.html":[3,0,180],
"mdaTalkBoxController_8cpp.html":[3,0,181],
"mdaTalkBoxController_8h.html":[3,0,182],
"mdaTalkBoxProcessor_8cpp.html":[3,0,183],
"mdaTalkBoxProcessor_8cpp.html#a3b947f4b635461030ff2d87833e5049e":[3,0,183,2],
"mdaTalkBoxProcessor_8cpp.html#abf940742e1b38f8100a344f9275d4086":[3,0,183,0],
"mdaTalkBoxProcessor_8cpp.html#ac263b7a2859108c07ccce4ea3afc3ae6":[3,0,183,1],
"mdaTalkBoxProcessor_8h.html":[3,0,184],
"mdaTestToneController_8cpp.html":[3,0,185],
"mdaTestToneController_8cpp.html#a46f7021143bf47d91deb328e111db545":[3,0,185,0],
"mdaTestToneController_8cpp.html#af90e2510c82d13f8b6b3248f9570bc49":[3,0,185,1],
"mdaTestToneController_8h.html":[3,0,186],
"mdaTestToneProcessor_8cpp.html":[3,0,187],
"mdaTestToneProcessor_8h.html":[3,0,188],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4":[3,0,188,1],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4a650be61892bf690026089544abbd9d26":[3,0,188,1,0],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4a69fc24f6dd1ad5005df611acf4229ace":[3,0,188,1,7],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4a778bbb350586657cc3127ef666a75618":[3,0,188,1,6],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4a781dc97dc62331eec3ea9ec4373a3ca8":[3,0,188,1,2],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4a8e9014ddfce21beb1b3cd7da888cbdea":[3,0,188,1,5],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4aa0db49ba470c1c9ae2128c3470339153":[3,0,188,1,1],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4ae1dffc8709f31a4987c8a88334107e89":[3,0,188,1,3],
"mdaTestToneProcessor_8h.html#ad4a12cdd49d69dab3151c2972b5e76a4afe5c3684dce76cdd9f7f42430868aa74":[3,0,188,1,4],
"mdaThruZeroController_8cpp.html":[3,0,189],
"mdaThruZeroController_8h.html":[3,0,190],
"mdaThruZeroProcessor_8cpp.html":[3,0,191],
"mdaThruZeroProcessor_8cpp.html#aa893c2c75e0d3d0258e09fbd136ffaed":[3,0,191,0],
"mdaThruZeroProcessor_8h.html":[3,0,192],
"mdaTrackerController_8cpp.html":[3,0,193],
"mdaTrackerController_8h.html":[3,0,194],
"mdaTrackerProcessor_8cpp.html":[3,0,195],
"mdaTrackerProcessor_8h.html":[3,0,196],
"mdafactory_8cpp.html":[3,0,109],
"mdafactory_8cpp.html#a7a6b11a55e9b38681d4d7941f3cd28d6":[3,0,109,0],
"namespaceSteinberg_1_1HostChecker.html":[2,0,0,2],
"namespaceSteinberg_1_1HostChecker.html":[1,0,0,2],
"namespaceSteinberg_1_1Panner.html":[2,0,0,3],
"namespaceSteinberg_1_1Panner.html":[1,0,0,3],
"namespaceSteinberg_1_1Vst_1_1AudioHost.html":[1,0,0,1,3],
"namespaceSteinberg_1_1Vst_1_1AudioHost.html":[2,0,0,1,3],
"namespaceSteinberg_1_1Vst_1_1EditorHost.html":[2,0,0,1,4],
"namespaceSteinberg_1_1Vst_1_1EditorHost.html":[1,0,0,1,4],
"namespaceSteinberg_1_1Vst_1_1LegacyMIDICCOut.html":[2,0,0,1,0],
"namespaceSteinberg_1_1Vst_1_1LegacyMIDICCOut.html":[1,0,0,1,0],
"namespaceSteinberg_1_1Vst_1_1NoteExpressionSynth.html":[1,0,0,1,2],
"namespaceSteinberg_1_1Vst_1_1NoteExpressionSynth.html":[2,0,0,1,2],
"namespaceSteinberg_1_1Vst_1_1mda.html":[2,0,0,1,1],
"namespaceSteinberg_1_1Vst_1_1mda.html":[1,0,0,1,1],
"namespacemembers.html":[1,1,0],
"namespacemembers_enum.html":[1,1,3],
"namespacemembers_eval.html":[1,1,4],
"namespacemembers_type.html":[1,1,2],
"namespacemembers_vars.html":[1,1,1],
"namespaces.html":[1,0],
"note__expression__synth_2source_2factory_8cpp.html":[3,0,38],
"note__expression__synth_2source_2factory_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,38,0],
"note__expression__synth_2source_2version_8h.html":[3,0,275],
"note__expression__synth_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,275,2],
"note__expression__synth_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,275,5],
"note__expression__synth_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,275,1],
"note__expression__synth_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,275,4],
"note__expression__synth_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,275,6],
"note__expression__synth_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,275,3],
"note__expression__synth_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,275,0],
"note__expression__synth__auv3_2audiounitconfig_8h.html":[3,0,21],
"note__expression__synth__auv3_2audiounitconfig_8h.html#a3cac5ff5fa6d00c89872bd159c33e552":[3,0,21,10],
"note__expression__synth__auv3_2audiounitconfig_8h.html#a4019d8ce3bdbd1f14eb6c6429cb097f9":[3,0,21,6],
"note__expression__synth__auv3_2audiounitconfig_8h.html#a476caadf14c9cb14d70ae895e4c5047f":[3,0,21,1],
"note__expression__synth__auv3_2audiounitconfig_8h.html#a673df5bd51e1927c698e4934cae14c98":[3,0,21,5],
"note__expression__synth__auv3_2audiounitconfig_8h.html#aa5487d926fdfe6333497df02061b0758":[3,0,21,0],
"note__expression__synth__auv3_2audiounitconfig_8h.html#aaf9e8ddda61d8ddd8ad10c507533643e":[3,0,21,12],
"note__expression__synth__auv3_2audiounitconfig_8h.html#ab4c92ba5e6b1c1d97773bf0cc84125bc":[3,0,21,3],
"note__expression__synth__auv3_2audiounitconfig_8h.html#abae7faa0480421761493fea8346c1587":[3,0,21,4],
"note__expression__synth__auv3_2audiounitconfig_8h.html#ad8225b98baf3f9d12f5f22981f990d53":[3,0,21,8],
"note__expression__synth__auv3_2audiounitconfig_8h.html#ad84fd3bf68b1aeebb32efab604f5dafd":[3,0,21,2],
"note__expression__synth__auv3_2audiounitconfig_8h.html#aec608402638dd0120398bda1074a4eb2":[3,0,21,7],
"note__expression__synth__auv3_2audiounitconfig_8h.html#af1327eb2e2055860752d5b164adc03cf":[3,0,21,9],
"note__expression__synth__auv3_2audiounitconfig_8h.html#af51e79c5ec243a082686a9f441aefafa":[3,0,21,11],
"note__expression__synth__controller_8cpp.html":[3,0,197],
"note__expression__synth__controller_8h.html":[3,0,198],
"note__expression__synth__controller_8h.html#a175afda9e102dad81527e8286041df73":[3,0,198,4],
"note__expression__synth__controller_8h.html#a3e41ba21c7275da72ab1d028c2ae6c3a":[3,0,198,3],
"note__expression__synth__controller_8h.html#a55d209b7b8449c2dde8d7c4545eddd64":[3,0,198,2],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a1fd60c9fd3b89595fd4fac5452a9eab0":[3,0,198,8],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a28e3fcf7199688b7cb545bc12d809b83":[3,0,198,10],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a305960e8a0a7efe8a230c54b0fae7241":[3,0,198,15],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a36f04f1c4ad888ed7950c98cadc0f5d2":[3,0,198,9],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a412ff72345b594894000c8f47b7f1921":[3,0,198,7],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a5e08b56cf242bca747e71a1db6d3e44d":[3,0,198,22],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a64027d24fafda77fee5484965c2a1f54":[3,0,198,16],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a6f57b4500838eed6d28cb3d0a18c2eac":[3,0,198,14],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a763d2b0b998e0befac498a6f85fb4586":[3,0,198,21],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a77d924fdebf79683bacdc950e8d97927":[3,0,198,13],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a90c528610d766ac690f4bdc610b54263":[3,0,198,19],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57a91f1716d5c6095299340b475b63dce2b":[3,0,198,5],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57aa1561f024a54fea5cbe44e301597ce49":[3,0,198,12],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57aaa0d2fa6e5ca05209a80bcd914c4af06":[3,0,198,6],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57ac1b7756581e9cdd3f3bdf949884f4eb1":[3,0,198,20],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57ac3653590a877c6bdf3792f59be40eb90":[3,0,198,11],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57ad33a80bac508a5fbe271f14a94203608":[3,0,198,17],
"note__expression__synth__controller_8h.html#ab04a0655cd1e3bcac5e8f48c18df1a57af6905f57b2a332b3be3f375a352f497f":[3,0,198,18],
"note__expression__synth__controller_8h.html#aca618e8fa76e4f9eaf21bef1d1ddccd5":[3,0,198,1],
"note__expression__synth__processor_8cpp.html":[3,0,199],
"note__expression__synth__processor_8h.html":[3,0,200],
"note__expression__synth__ui_8cpp.html":[3,0,201],
"note__expression__synth__ui_8cpp.html#a385c44f6fb256e5716a2302a5b940388a529b59e28a1ca482d2acdd7e5a098d7b":[3,0,201,1],
"note__expression__synth__ui_8cpp.html#a385c44f6fb256e5716a2302a5b940388af5404385ef1048d1e74993a409b6f030":[3,0,201,0],
"note__expression__synth__ui_8h.html":[3,0,202],
"note__expression__synth__voice_8cpp.html":[3,0,203],
"note__expression__synth__voice_8h.html":[3,0,204],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45d":[3,0,204,4],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da0ac26f0bf0461b55b596412ebb5c25b5":[3,0,204,4,2],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da122461f98d458fb93eae02df5e8337a5":[3,0,204,4,5],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da1dfc7e7be1ba07eb4144e11e6ffa3d84":[3,0,204,4,14],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da28142103b5ea374bc2dfada4f38f43cf":[3,0,204,4,3],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da41892a7e572e701bbb31e27d7882b939":[3,0,204,4,8],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da5e10b316568bc305dce5048b0b4aa179":[3,0,204,4,0],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45da912bfe48653cc16464d18085c3755f6d":[3,0,204,4,4],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45daa1c0099aaa84b41e977bdbd88193d73f":[3,0,204,4,10],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45daac6a071b53c40d42d7d1a0a57a7253dc":[3,0,204,4,12],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45dab46457a150a5aa8387470b45e110689d":[3,0,204,4,6],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45dac27d14ab31c50dc10de9c0957203b738":[3,0,204,4,7],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45dace5a49d9700610738ba0da1b54f4df8c":[3,0,204,4,11],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45daecbdbeaa9511062f941714bbf20622ea":[3,0,204,4,9],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45daef4d8aa59cba7c34e5d7cd6844caa877":[3,0,204,4,1],
"note__expression__synth__voice_8h.html#a1ce3513d3c756afe6a0aecc8b8e7d45daf461c3668475e9f0359286d19ca24e54":[3,0,204,4,13],
"note__expression__synth__voice_8h.html#a2b12f538abaa78f3020c16a431d4eeb5":[3,0,204,3],
"note__expression__text_2source_2plug_8cpp.html":[3,0,215],
"note__expression__text_2source_2plug_8h.html":[3,0,220],
"note__expression__text_2source_2plugcids_8h.html":[3,0,225],
"note__expression__text_2source_2plugcontroller_8cpp.html":[3,0,230],
"note__expression__text_2source_2plugcontroller_8h.html":[3,0,236],
"note__expression__text_2source_2plugentry_8cpp.html":[3,0,241],
"note__expression__text_2source_2plugentry_8cpp.html#a1075637db8f5731ef803159910f409f8":[3,0,241,1],
"note__expression__text_2source_2plugentry_8cpp.html#a53ac779212edf501532da8751b27572c":[3,0,241,3],
"note__expression__text_2source_2plugentry_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,241,0],
"note__expression__text_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357":[3,0,241,2],
"note__expression__text_2source_2plugentry_8cpp.html#ac09825b56d6a6e6099918f3b532a58b2":[3,0,241,4]
};
